@@ -92,10 +92,6 @@ def parse_args():
                              "adjustable parameter sets or repeats "
                              "are used.")
 
-    parser.add_argument('-u', '--UV', type=float, default=1.0,
-                        help="Value for the UV parameter for the model "
-                             "(default is 1.0)")
-
     parser.add_argument('-d', '--disease', type=str, default=None,
                         help="Name of the disease to model "
                              "(default is 'ncov')")
@@ -137,11 +133,17 @@ def parse_args():
     parser.add_argument('-P', '--population', type=int, default=57104043,
                         help="Initial population (default 57104043)")
 
-    parser.add_argument('-n', '--nsteps', type=int, default=None,
+    parser.add_argument('-n', '--nsteps', type=int, default=730,
                         help="Maximum number of steps (days) to run for the "
                              "simulation. Each step represents one day in the "
-                             "outbreak (default is to run until the "
-                             "outbreak has finished).")
+                             "outbreak (default is to run for a maximum "
+                             "of two years - 730 days)")
+
+    parser.add_argument('-u', '--user-variables', type=str, default=None,
+                        help="Name of the file containing user-defined "
+                             "custom variables. These provide extra "
+                             "information that can be read by the "
+                             "custom integrators or custom extractors.")
 
     parser.add_argument('--iterator', type=str, default=None,
                         help="Name of the iterator to use to advance the "
@@ -155,6 +157,10 @@ def parse_args():
                              "explanation see the tutorial at "
                              "https://metawards.github.io")
 
+    parser.add_argument('--UV', type=float, default=0.0,
+                        help="Value for the UV parameter for the model "
+                             "(default is 0.0)")
+
     parser.add_argument('--nthreads', type=int, default=None,
                         help="Number of threads over which parallelise an "
                              "individual model run. The total number of "
@@ -801,13 +807,13 @@ def cli():
               f"default is $HOME/GitHub/MetaWardsData")
         raise e
 
-    # should we profile the code? (default yes, as it doesn't cost anything)
-    profile = args.profile
+    # should we profile the code? (default no as it prints a lot)
+    profile = False
 
     if args.no_profile:
         profile = False
-    elif profile is None:
-        profile = False
+    elif args.profile:
+        profile = True
 
     # load the disease and starting-point input files
     if args.disease:
@@ -817,6 +823,12 @@ def cli():
 
     params.set_input_files(args.input_data)
 
+    # load the user-defined custom parameters
+    if args.user_variables:
+        custom = VariableSet.read(args.user_variables)
+        print(f"Adjusting variables to {custom}")
+        custom.adjust(params)
+
     # read the additional seeds
     if args.additional is None or len(args.additional) == 0:
         print("Not using any additional seeds...")
