@@ -21,13 +21,13 @@ def iterate_weekday(nthreads: int = 1, **kwargs):
     """
 
     if nthreads is None or nthreads == 1:
-        from ._advance_infprob import advance_infprob
-        from ._advance_fixed import advance_fixed
-        from ._advance_play import advance_play
+        from ._advance_infprob import advance_infprob_serial
+        from ._advance_fixed import advance_fixed_serial
+        from ._advance_play import advance_play_serial
 
-        funcs = [advance_infprob,
-                 advance_fixed,
-                 advance_play]
+        funcs = [advance_infprob_serial,
+                 advance_fixed_serial,
+                 advance_play_serial]
     else:
         from ._advance_infprob import advance_infprob_omp
         from ._advance_fixed import advance_fixed_omp
